Imports Microsoft.VisualBasic
Imports System
Imports System.Drawing
Imports System.Windows.Forms
Imports Telerik.WinControls
Imports Telerik.WinControls.UI
Imports Telerik.WinControls.Layouts

Namespace TelerikEditor
	Public Class RadMenuInsertTableItem
		Inherits RadMenuItemBase
		#Region "Constants"

		Private Const HeaderText As String = "Insert Table"

		#End Region

		#Region "Fields"

		Private uniformGrid As UniformGrid
		Private header As LightVisualElement
		Private stackLayout As StackLayoutElement
		Private currentColumnIndex As Integer = -1
		Private currentRowIndex As Integer = -1

		#End Region

		#Region "Intialization"

		Protected Overrides Sub InitializeFields()
			MyBase.InitializeFields()
			Me.ShouldHandleMouseInput = True
		End Sub

		Protected Overrides Sub CreateChildElements()
			MyBase.CreateChildElements()

			Dim rowsCount As Integer = 8
			Dim columnsCount As Integer = 10
			Dim boxSize As Size = New Size(16, 16)

			Me.stackLayout = New StackLayoutElement()
			Me.stackLayout.Orientation = Orientation.Vertical
			Me.stackLayout.StretchHorizontally = True
			Me.stackLayout.StretchVertically = True
			Me.stackLayout.NotifyParentOnMouseInput = True
			Me.Children.Add(Me.stackLayout)

			Me.header = New LightVisualElement()
			Me.header.TextAlignment = ContentAlignment.MiddleLeft
			Me.header.StretchVertically = False
			Me.header.Text = RadMenuInsertTableItem.HeaderText
			Me.header.DrawFill = True
			Me.header.Font = New Font("Segoe UI", 9, FontStyle.Bold)
			Me.header.GradientStyle = GradientStyles.Solid
			Me.header.BackColor = Color.FromArgb(240, 242, 245)
			Me.stackLayout.Children.Add(Me.header)

			Me.uniformGrid = New UniformGrid()
			Me.uniformGrid.StretchVertically = True
			Me.uniformGrid.NotifyParentOnMouseInput = True
			Me.uniformGrid.Rows = rowsCount
			Me.uniformGrid.Columns = columnsCount
			Me.uniformGrid.MinSize = New Size(160, 140)
			Me.uniformGrid.Margin = New Padding(5, 5, 0, 0)
			Me.stackLayout.Children.Add(Me.uniformGrid)

			Dim i As Integer = 1
			Do While i <= rowsCount * columnsCount
				Dim box As LightVisualElement = New LightVisualElement()
				box.DrawBorder = True
				box.BorderGradientStyle = GradientStyles.Solid
				box.BorderBoxStyle = BorderBoxStyle.OuterInnerBorders
				box.MaxSize = boxSize
				box.MinSize = boxSize
				box.NotifyParentOnMouseInput = True
				AddHandler box.MouseMove, AddressOf OnBoxMouseMove
				AddHandler box.MouseDown, AddressOf OnBoxMouseDown
				Me.uniformGrid.Children.Add(box)
				i += 1
			Loop
		End Sub

		#End Region

		#Region "Properties"

		Protected Overrides ReadOnly Property ThemeEffectiveType() As Type
			Get
				Return GetType(RadMenuItem)
			End Get
		End Property

		#End Region

		#Region "Events"

		Public Event SelectionChanged As EventHandler(Of TableSelectionChangedEventArgs)

		Protected Overridable Sub OnSelectionChanged(ByVal e As TableSelectionChangedEventArgs)
			Dim handler As EventHandler(Of TableSelectionChangedEventArgs) = Me.SelectionChangedEvent

			If Not handler Is Nothing Then
				handler(Me, e)
			End If

			Dim buttonElement As RadDropDownButtonElement = TryCast(Me.Owner, RadDropDownButtonElement)

			If Not buttonElement Is Nothing Then
				buttonElement.DropDownMenu.ClosePopup(RadPopupCloseReason.Mouse)
				Me.ResetVisuals()
			End If
		End Sub

		Private Sub ResetVisuals()
			Me.header.Text = RadMenuInsertTableItem.HeaderText

			For Each element As LightVisualElement In Me.uniformGrid.Children
				element.ResetValue(LightVisualElement.BorderColorProperty, ValueResetFlags.Local)
				element.ResetValue(LightVisualElement.BorderInnerColorProperty, ValueResetFlags.Local)
			Next element
		End Sub

		Private Sub OnBoxMouseMove(ByVal sender As Object, ByVal e As MouseEventArgs)
			Me.SelectBoxes(e.Location)
		End Sub

		Protected Overrides Sub OnMouseMove(ByVal e As MouseEventArgs)
			MyBase.OnMouseMove(e)
			Me.SelectBoxes(e.Location)
		End Sub

		Private Sub OnBoxMouseDown(ByVal sender As Object, ByVal e As MouseEventArgs)
			Me.OnSelectionChanged(New TableSelectionChangedEventArgs(currentColumnIndex, currentRowIndex))
		End Sub

		Protected Overrides Sub OnMouseDown(ByVal e As MouseEventArgs)
			MyBase.OnMouseDown(e)

			If e.Button = MouseButtons.Left Then
				Me.OnSelectionChanged(New TableSelectionChangedEventArgs(currentColumnIndex, currentRowIndex))
			End If
		End Sub

		Protected Overrides Sub OnPropertyChanged(ByVal e As RadPropertyChangedEventArgs)
			MyBase.OnPropertyChanged(e)

			If e.Property Is LightVisualElement.ContainsMouseProperty Then
				If (Not CBool(e.NewValue)) Then
					Me.ResetVisuals()
				End If
			End If
		End Sub

		#End Region

		#Region "Methods"

		Private Sub SelectBoxes(ByVal location As Point)
			Me.currentColumnIndex = -1
			Me.currentRowIndex = -1

			For Each element As LightVisualElement In Me.uniformGrid.Children
				Dim elementBounds As RectangleF = element.ControlBoundingRectangle

				If elementBounds.X <= location.X AndAlso elementBounds.Y <= location.Y Then
					Dim columnIndex As Integer = UniformGrid.GetColumnIndex(element)
					Dim rowIndex As Integer = UniformGrid.GetRowIndex(element)

					currentColumnIndex = Math.Max(currentColumnIndex, columnIndex)
					currentRowIndex = Math.Max(currentRowIndex, rowIndex)

					element.BorderColor = Color.DarkOrange
					element.BorderInnerColor = Color.OrangeRed
				Else
					element.ResetValue(LightVisualElement.BorderColorProperty, ValueResetFlags.Local)
					element.ResetValue(LightVisualElement.BorderInnerColorProperty, ValueResetFlags.Local)
				End If
			Next element

			Dim text As String = RadMenuInsertTableItem.HeaderText

			If currentColumnIndex >= 0 AndAlso currentRowIndex >= 0 Then
				text = String.Format("{0}x{1}", currentColumnIndex + 1, currentRowIndex + 1)
			End If

			Me.header.Text = text
		End Sub

		#End Region

		#Region "Layout"

		Protected Overrides Function ArrangeOverride(ByVal finalSize As SizeF) As SizeF
			Dim menuLayout As RadDropDownMenuLayout = TryCast(Me.Parent, RadDropDownMenuLayout)
			Dim x As Single = Math.Max(menuLayout.LeftColumnWidth, menuLayout.LeftColumnMinWidth) + menuLayout.LeftColumnMaxPadding

			Dim size As SizeF = finalSize
			size.Width -= x

			Dim finalRect As RectangleF = New RectangleF(New PointF(x, 0), size)

			Me.stackLayout.Arrange(finalRect)
			Return finalSize
		End Function

		#End Region
	End Class
End Namespace
