Imports Microsoft.VisualBasic
Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Drawing
Imports System.Drawing.Text
Imports System.IO
Imports System.Threading
Imports System.Windows.Forms
Imports Telerik.WinControls
Imports Telerik.WinControls.Enumerations
Imports Telerik.WinControls.RichTextBox
Imports Telerik.WinControls.RichTextBox.FileFormats.Html
Imports Telerik.WinControls.RichTextBox.FileFormats.OpenXml.Docx
Imports Telerik.WinControls.RichTextBox.FileFormats.Pdf
Imports Telerik.WinControls.RichTextBox.FileFormats.Rtf
Imports Telerik.WinControls.RichTextBox.FileFormats.Xaml
Imports Telerik.WinControls.RichTextBox.FormatProviders
Imports Telerik.WinControls.RichTextBox.FormatProviders.Txt
Imports Telerik.WinControls.RichTextBox.Layout
Imports Telerik.WinControls.RichTextBox.Lists
Imports Telerik.WinControls.RichTextBox.Model
Imports Telerik.WinControls.RichTextBox.Model.Styles
Imports Telerik.WinControls.RichTextBox.UI
Imports Telerik.WinControls.UI

Namespace TelerikEditor
	Public Partial Class MainForm
		Inherits RadRibbonForm
		Private stylesInitializing As Boolean = False
		Private firstShow As Boolean = True
		Private singleInstance As Boolean
		Private closeTimer As System.Windows.Forms.Timer

		Public Sub New()
			Initialize()
		End Sub

		Public Sub New(ByVal singleInstance As Boolean)
			' TODO: Complete member initialization
			Me.singleInstance = singleInstance
			Me.Opacity = 0
			Me.ShowInTaskbar = False

			Initialize()
		End Sub

		Private Sub Initialize()
			InitializeComponent()


			Dim insertTableBoxItem As RadMenuInsertTableItem = New RadMenuInsertTableItem()
			Me.radDropDownButtonElementTables.Items.Insert(0, insertTableBoxItem)
            AddHandler insertTableBoxItem.SelectionChanged,
                AddressOf OnInsertTableSelectionChanged

			AddHandler radMenuItemInsertTable.Click, AddressOf radMenuItemInsertTable_Click
			ThemeResolutionService.ApplicationThemeName = "Office2010Blue"

			Me.radRibbonBar1.RibbonBarElement.ApplicationButtonElement.Text = "File"
			Me.radRibbonBar1.RibbonBarElement.ApplicationButtonElement.ForeColor = Color.White
			Me.radRibbonBar1.RibbonBarElement.ApplicationButtonElement.DisplayStyle = DisplayStyle.Text

			Me.radDropDownListFontSize.DropDownStyle = RadDropDownStyle.DropDownList
			Me.radDropDownListFont.DropDownStyle = RadDropDownStyle.DropDownList

			Me.radPageView1.SelectedPage = Me.radPageViewPageSaveAsWord

			Dim docxProvider As DocxFormatProvider = New DocxFormatProvider()
            Dim document As RadDocument = docxProvider.Import(My.Resources.RichTextBox_for_WinForms)
			Me.AttachDocument(document)
			Me.radRichTextBox1.Document = document
			Me.radBtnPrintLayout.ToggleState = ToggleState.On
			AddHandler radRichTextBox1.CurrentEditingStyleChanged, AddressOf radRichTextBox1_CurrentEditingStyleChanged

			AddHandler radPageViewPageSaveAsHtml.Item.Click, AddressOf radBtnSave_Click
			AddHandler radPageViewPageSaveAsPDF.Item.Click, AddressOf radBtnSave_Click
			AddHandler radPageViewPageSaveAsRTF.Item.Click, AddressOf radBtnSave_Click
			AddHandler radPageViewPageSaveAsText.Item.Click, AddressOf radBtnSave_Click
			AddHandler radPageViewPageSaveAsWord.Item.Click, AddressOf radBtnSave_Click
			AddHandler radPageViewPageSaveAsXAML.Item.Click, AddressOf radBtnSave_Click

			Me.radDropDownListFont.DropDownAnimationEnabled = False
			Me.radDropDownListFontSize.DropDownAnimationEnabled = False

			Me.closeTimer = New System.Windows.Forms.Timer()
			Me.closeTimer.Interval = 3000
			AddHandler closeTimer.Tick, AddressOf closeTimer_Tick
			Me.closeTimer.Start()
		End Sub

		Private Sub InitializeUI()
			Me.stylesInitializing = True
			Dim styleDefinition As StyleDefinition = Me.radRichTextBox1.CurrentEditingStyle
			Me.InitializeCurrentFontStyles(styleDefinition)
			Me.InitializeCurrentParagraphStyles(styleDefinition)

			Dim baselineAlignment__1 As BaselineAlignment = DirectCast(styleDefinition.GetPropertyValue(Span.BaselineAlignmentProperty), BaselineAlignment)
            Me.subscriptButtonElement.ToggleState = If(baselineAlignment__1 = BaselineAlignment.Subscript, ToggleState.[On], ToggleState.Off)
            Me.superscriptButtonElement.ToggleState = If(baselineAlignment__1 = BaselineAlignment.Superscript, ToggleState.[On], ToggleState.Off)

			Me.stylesInitializing = False
		End Sub

		Private Sub InitializeCurrentFontStyles(ByVal styleDefinition As StyleDefinition)
			Dim underlineType As UnderlineType = CType(styleDefinition.GetPropertyValue(Span.UnderlineTypeProperty), UnderlineType)
			Me.radBtnUnderlineStyle.ToggleState = If(underlineType <> UnderlineType.None, ToggleState.[On], ToggleState.Off)

			Dim fontFamiliy As String = CStr(styleDefinition.GetPropertyValue(Span.FontFamilyProperty))
			Me.radDropDownListFont.SuspendSelectionEvents = True
			Me.radDropDownListFont.Text = fontFamiliy
			Me.radDropDownListFont.SelectedValue = fontFamiliy
			Me.radDropDownListFont.SuspendSelectionEvents = False

			Dim fontSize As Single = CSng(styleDefinition.GetPropertyValue(Span.FontSizeProperty))
			fontSize = CSng(Math.Round(Unit.DipToPoint(fontSize), 1))
			Me.EnsureFontSize(fontSize.ToString())

			Dim fontStyle As TextStyle = CType(styleDefinition.GetPropertyValue(Span.FontStyleProperty), TextStyle)

			If fontStyle.HasFlag(TextStyle.Bold) Then
				Me.radBtnBoldStyle.ToggleState = ToggleState.On
			Else
				Me.radBtnBoldStyle.ToggleState = ToggleState.Off
			End If
			If fontStyle.HasFlag(TextStyle.Italic) Then
				Me.radBtnItalicStyle.ToggleState = ToggleState.On
			Else
				Me.radBtnItalicStyle.ToggleState = ToggleState.Off
			End If

			Dim strikeThrough As Boolean = CBool(styleDefinition.GetPropertyValue(Span.StrikethroughProperty))
			If strikeThrough Then
				Me.radBtnStrikethrough.ToggleState = ToggleState.On
			Else
				Me.radBtnStrikethrough.ToggleState = ToggleState.Off
			End If
		End Sub

		Private Sub InitializeCurrentParagraphStyles(ByVal styleDefinition As StyleDefinition)
			Dim paragraph As Paragraph = Me.radRichTextBox1.Document.CaretPosition.GetCurrentParagraphBox().AssociatedParagraph
			Dim textAlignment As RadTextAlignment = paragraph.TextAlignment

			Me.radBtnAligntLeft.ToggleState = If(textAlignment = RadTextAlignment.Left, ToggleState.[On], ToggleState.Off)
            Me.radBtnAlignCenter.ToggleState = If(textAlignment = RadTextAlignment.Center, ToggleState.[On], ToggleState.Off)
            Me.radBtnAligntRight.ToggleState = If(textAlignment = RadTextAlignment.Right, ToggleState.[On], ToggleState.Off)
            Me.radBtnAlignJustify.ToggleState = If(textAlignment = RadTextAlignment.Justify, ToggleState.[On], ToggleState.Off)

			Dim format As Nullable(Of ListNumberingFormat) = Nothing

			If paragraph.IsInList Then
				format = paragraph.ListItemInfo.List.Style.Levels(paragraph.ListItemInfo.ListLevel).NumberingFormat
			End If

			If format.Equals(ListNumberingFormat.Bullet) Then
				Me.radBtnBulletList.ToggleState = ToggleState.On
			Else
				Me.radBtnBulletList.ToggleState = ToggleState.Off
			End If

			If format.Equals(ListNumberingFormat.Decimal) Then
				Me.radNumberingList.ToggleState = ToggleState.On
			Else
				Me.radNumberingList.ToggleState = ToggleState.Off
			End If
		End Sub

		Private Sub AttachDocument(ByVal document As RadDocument)
			AddHandler document.PropertyChanged, AddressOf Document_PropertyChanged
		End Sub

		Private Sub DetachDocument(ByVal document As RadDocument)
			RemoveHandler document.PropertyChanged, AddressOf Document_PropertyChanged
		End Sub

		Private Shared Sub ExitApp(ByVal sync As Object)
			Dim mutex As Mutex = TryCast(sync, Mutex)
			mutex.WaitOne()

			Application.Exit()
		End Sub

		Private Sub EnsureFontSize(ByVal fontSize As String)
			Me.radDropDownListFontSize.SuspendSelectionEvents = True

			For Each item As RadListDataItem In Me.radDropDownListFontSize.Items
				If String.Compare(item.Text, fontSize) = 0 Then
					Me.radDropDownListFontSize.SelectedIndex = item.RowIndex
					Me.radDropDownListFontSize.Text = item.Text
					Me.radDropDownListFontSize.SuspendSelectionEvents = False
					Return
				End If
			Next item

			Me.radDropDownListFontSize.Text = fontSize
			Me.radDropDownListFontSize.SelectedIndex = -1

			Me.radDropDownListFontSize.SuspendSelectionEvents = False
		End Sub

		Private Sub OpenDocument()
			Using openDialog As OpenFileDialog = New OpenFileDialog()
				openDialog.Filter = "Word Documents (*.docx)|*.docx|Web Pages (*.htm,*.html)|*.htm;*.html|Rich Text Format (*.rtf)|*.rtf|Text Files (*.txt)|*.txt|XAML Files (*.xaml)|*.xaml"

				If openDialog.ShowDialog() = System.Windows.Forms.DialogResult.OK Then
					Dim extension As String = Path.GetExtension(openDialog.SafeFileName).ToLower()

					Dim provider As IDocumentFormatProvider = GetProviderByExtension(extension)

					If provider Is Nothing Then
						RadMessageBox.Show("Unable to find format provider for extension " & extension, "Error")
						Return
					End If

					Using stream As Stream = openDialog.OpenFile()
						Dim document As RadDocument = provider.Import(stream)
						Me.DetachDocument(Me.radRichTextBox1.Document)
						Me.radRichTextBox1.Document = document
						Me.AttachDocument(document)
						document.LayoutMode = DocumentLayoutMode.Paged
					End Using
				End If

				Me.radRichTextBox1.Focus()
			End Using
		End Sub

		Private Sub SaveDocument(ByVal format As String)
			Using saveDialog As SaveFileDialog = New SaveFileDialog()
				If format = "docx" Then
					saveDialog.Filter = "Word Document (*.docx)|*.docx"
				ElseIf format = "rtf" Then
					saveDialog.Filter = "Rich Text Format (*.rtf)|*.rtf"
				ElseIf format = "html" Then
					saveDialog.Filter = "Web Page (*.html)|*.html"
				ElseIf format = "xaml" Then
					saveDialog.Filter = "XAML File (*.xaml)|*.xaml"
				ElseIf format = "txt" Then
					saveDialog.Filter = "Text File (*.txt)|*.txt"
				ElseIf format = "pdf" Then
					saveDialog.Filter = "PDF File (*.pdf)|*.pdf"
				Else
					saveDialog.Filter = "Word Document (*.docx)|*.docx|PDF File (*.pdf)|*.pdf|Web Page (*.html)|*.html|Rich Text Format (*.rtf)|*.rtf|Text File (*.txt)|*.txt|XAML File (*.xaml)|*.xaml"
				End If

				If saveDialog.ShowDialog() = System.Windows.Forms.DialogResult.OK Then
					Dim extension As String = System.IO.Path.GetExtension(saveDialog.FileName)

					Dim provider As IDocumentFormatProvider = GetProviderByExtension(extension)

					If provider Is Nothing Then
						RadMessageBox.Show("Unable to find format provider for extension " & extension, "Error")
						Return
					End If

					Using output As Stream = saveDialog.OpenFile()
						provider.Export(Me.radRichTextBox1.Document, output)
					End Using
				End If

				Me.radRichTextBox1.Focus()
			End Using
		End Sub

		Private Function GetProviderByExtension(ByVal extension As String) As IDocumentFormatProvider
			If extension = ".xaml" Then
				Return New XamlFormatProvider()
			End If

			If extension = ".docx" Then
				Return New DocxFormatProvider()
			End If

			If extension = ".rtf" Then
				Return New RtfFormatProvider()
			End If

			If extension = ".html" OrElse extension = ".htm" Then
				Return New HtmlFormatProvider()
			End If

			If extension = ".txt" Then
				Return New TxtFormatProvider()
			End If

			If extension = ".pdf" Then
				Return New PdfFormatProvider()
			End If

			Return Nothing
		End Function

		#Region "Event handlers"

		Protected Overrides Overloads Sub OnLoad(ByVal e As System.EventArgs)
			MyBase.OnLoad(e)

			Dim font As InstalledFontCollection = New InstalledFontCollection()

			Dim families As List(Of String) = New List(Of String)()

			For Each familiy As FontFamily In font.Families
				If familiy.IsStyleAvailable(FontStyle.Regular) AndAlso familiy.IsStyleAvailable(FontStyle.Italic) AndAlso familiy.IsStyleAvailable(FontStyle.Bold) Then
					families.Add(familiy.Name)
				End If
			Next familiy

			Me.radDropDownListFont.DataSource = families

			Me.InitializeUI()
		End Sub

		Protected Overrides Sub OnShown(ByVal e As EventArgs)
			MyBase.OnShown(e)

			If Me.singleInstance Then
				If firstShow Then
					Me.Visible = False
					Me.firstShow = False
					Me.Opacity = 1
				Else
					Me.ShowInTaskbar = True
				End If
			End If
		End Sub

		Protected Overrides Sub OnClosing(ByVal e As CancelEventArgs)
			If singleInstance Then
				e.Cancel = True
				Me.Hide()
			End If

			MyBase.OnClosing(e)
		End Sub

		Private Sub OnInsertTableSelectionChanged(ByVal sender As Object, ByVal e As TableSelectionChangedEventArgs)
			If e.RowIndex >= 0 AndAlso e.ColumnIndex >= 0 Then
				Me.radRichTextBox1.InsertTable(e.RowIndex + 1, e.ColumnIndex + 1)
			End If
		End Sub

		Private Sub closeTimer_Tick(ByVal sender As Object, ByVal e As EventArgs)
            Dim process__1 As Process() = Process.GetProcessesByName("TelerikExamples")
            If process__1.Length = 0 Then
                Me.closeTimer.Stop()
                Me.closeTimer.Dispose()

                If Me.Visible Then
                    Me.singleInstance = False
                Else
                    Application.Exit()
                End If
            End If
		End Sub

		Private Sub radRichTextBox1_CurrentEditingStyleChanged(ByVal sender As Object, ByVal e As EventArgs)
			Me.InitializeUI()
		End Sub

		Private Sub Document_PropertyChanged(ByVal sender As Object, ByVal e As System.ComponentModel.PropertyChangedEventArgs)
			Dim document As RadDocument = TryCast(sender, RadDocument)
			If document.LayoutMode = DocumentLayoutMode.Paged Then
				Me.radBtnPrintLayout.ToggleState = ToggleState.On
			Else
				Me.radBtnPrintLayout.ToggleState = ToggleState.Off
			End If
			If document.LayoutMode = DocumentLayoutMode.Flow Then
				Me.radBtnWebLayout.ToggleState = ToggleState.On
			Else
				Me.radBtnWebLayout.ToggleState = ToggleState.Off
			End If
		End Sub

		Private Sub radDropDownListFont_SelectedIndexChanged(ByVal sender As Object, ByVal e As Telerik.WinControls.UI.Data.PositionChangedEventArgs) Handles radDropDownListFont.SelectedIndexChanged
			Me.radRichTextBox1.ChangeFontFamily(Convert.ToString(Me.radDropDownListFont.SelectedValue))
			Me.radDropDownListFont.ClosePopup()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radDropDownListFontSize_SelectedIndexChanged(ByVal sender As Object, ByVal e As Telerik.WinControls.UI.Data.PositionChangedEventArgs) Handles radDropDownListFontSize.SelectedIndexChanged
			If Not Me.radDropDownListFontSize.SelectedItem Is Nothing Then
				Dim selectedText As String = Me.radDropDownListFontSize.SelectedItem.Text
				Dim fontSize As Single = Single.Parse(selectedText)
				fontSize = CSng(Math.Round(Unit.PointToDip(fontSize), 1))
				Me.radRichTextBox1.ChangeFontSize(fontSize)
				Me.radDropDownListFontSize.ClosePopup()
				Me.radRichTextBox1.Focus()
			End If
		End Sub

		Private Sub radMenuItemOpenDoc_Click(ByVal sender As Object, ByVal e As EventArgs) Handles backstageButtonOpen.Click, radMenuItemOpenDoc.Click
			Me.radRibbonBar1.BackstageControl.HidePopup()
			Me.OpenDocument()
		End Sub

		Private Sub radBtnSave_Click(ByVal sender As Object, ByVal e As EventArgs) Handles backstageButtonSave.Click, radBtnSave.Click, radMenuItemSave.Click, radMenuItemSaveAs.Click, radMenuItemSaveWordDoc.Click, radMenuItemSavePDFDocument.Click, radMenuItemSaveHtmlDocument.Click, radMenutItemSaveRTF.Click, radMenuItemSavePlainText.Click, radMenuItemSaveXAML.Click
			Dim format As String = Nothing

			If sender Is Me.radMenuItemSaveHtmlDocument OrElse sender Is Me.radPageViewPageSaveAsHtml.Item Then
				format = "html"
			ElseIf sender Is Me.radMenuItemSavePDFDocument OrElse sender Is Me.radPageViewPageSaveAsPDF.Item Then
				format = "pdf"
			ElseIf sender Is Me.radMenuItemSavePlainText OrElse sender Is Me.radPageViewPageSaveAsText.Item Then
				format = "txt"
			ElseIf sender Is Me.radMenuItemSaveWordDoc OrElse sender Is Me.radPageViewPageSaveAsWord.Item Then
				format = "docx"
			ElseIf sender Is Me.radMenuItemSaveXAML OrElse sender Is Me.radPageViewPageSaveAsXAML.Item Then
				format = "xaml"
			ElseIf sender Is Me.radMenutItemSaveRTF OrElse sender Is Me.radPageViewPageSaveAsRTF.Item Then
				format = "rtf"
			End If

			Me.radRibbonBar1.BackstageControl.HidePopup()
			Me.SaveDocument(format)
		End Sub

		Private Sub radMenuItemNew_Click(ByVal sender As Object, ByVal e As EventArgs) Handles backstageButtonNew.Click, radMenuItemNew.Click
			If RadMessageBox.Show("Do you want to save changes you made to Document1?", "Telerik Word", MessageBoxButtons.YesNo, RadMessageIcon.Question) = System.Windows.Forms.DialogResult.Yes Then
				Me.SaveDocument(Nothing)
			End If

			Me.DetachDocument(Me.radRichTextBox1.Document)
			Me.radRichTextBox1.Document = New RadDocument()
			Me.AttachDocument(Me.radRichTextBox1.Document)
			Me.radRichTextBox1.LayoutMode = DocumentLayoutMode.Paged
			Me.radRibbonBar1.BackstageControl.HidePopup()
		End Sub

		Private Sub radMenuItemLandscape_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemLandscape.Click
			Me.radRichTextBox1.ChangeSectionPageOrientation(PageOrientation.Landscape)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemPortrait_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemPortrait.Click
			Me.radRichTextBox1.ChangeSectionPageOrientation(PageOrientation.Portrait)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemRotate180_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemRotate180.Click
			Me.radRichTextBox1.ChangeSectionPageOrientation(PageOrientation.Rotate180)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemRotate270_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemRotate270.Click
			Me.radRichTextBox1.ChangeSectionPageOrientation(PageOrientation.Rotate270)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemModerate_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemModerate.Click
			Me.radRichTextBox1.ChangeSectionMargin(PageMarginTypesConverter.ToPadding(PageMarginTypes.Moderate))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemNarrow_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemNarrow.Click
			Me.radRichTextBox1.ChangeSectionMargin(PageMarginTypesConverter.ToPadding(PageMarginTypes.Narrow))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemNormal_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemNormal.Click
			Me.radRichTextBox1.ChangeSectionMargin(PageMarginTypesConverter.ToPadding(PageMarginTypes.Normal))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemOffice2003_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemOffice2003.Click
			Me.radRichTextBox1.ChangeSectionMargin(PageMarginTypesConverter.ToPadding(PageMarginTypes.Office2003))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemSizeA0_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemSizeA0.Click
			Me.radRichTextBox1.ChangePageSize(PaperTypeConverter.ToSize(PaperTypes.A0))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemSizeA1_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemSizeA1.Click
			Me.radRichTextBox1.ChangePageSize(PaperTypeConverter.ToSize(PaperTypes.A1))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemSizeA2_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemSizeA2.Click
			Me.radRichTextBox1.ChangePageSize(PaperTypeConverter.ToSize(PaperTypes.A2))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemSizeA3_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemSizeA3.Click
			Me.radRichTextBox1.ChangePageSize(PaperTypeConverter.ToSize(PaperTypes.A3))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemSizeA4_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radMenuItemSizeA4.Click
			Me.radRichTextBox1.ChangePageSize(PaperTypeConverter.ToSize(PaperTypes.A4))
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub backstageButtonItemExit_Click(ByVal sender As Object, ByVal e As EventArgs) Handles backstageButtonItemExit.Click
			Me.Close()
		End Sub

		Private Sub hyperlinkButtonElement_Click(ByVal sender As Object, ByVal e As EventArgs) Handles hyperlinkButtonElement.Click
			Me.radRichTextBox1.DocumentView.ShowInsertHyperlinkDialog()
		End Sub

		Private Sub bookmarkButtonElement_Click(ByVal sender As Object, ByVal e As EventArgs) Handles bookmarkButtonElement.Click
			Me.radRichTextBox1.DocumentView.ShowManageBookmarksDialog()
		End Sub

		Private Sub radBtnBackColor_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnBackColor.Click
			Dim colorDialog As RadColorDialog = New RadColorDialog()

			If colorDialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
				Me.radRichTextBox1.ChangeParagraphBackground(colorDialog.SelectedColor)
			End If

			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnEnableSpellCheck_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnEnableSpellCheck.Click
			Dim enabled As Boolean = Me.radRichTextBox1.IsSpellCheckingEnabled
			Me.radRichTextBox1.IsSpellCheckingEnabled = Not enabled
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnPageBreak_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radBtnPageBreak.Click
			Me.radRichTextBox1.InsertPageBreak()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnInsertPicture_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radBtnInsertPicture.Click
			Using openDialog As OpenFileDialog = New OpenFileDialog()
				openDialog.Filter = "JPEG Files (*.jpeg)|*.jpeg|PNG Files (*.png)|*.png|JPG Files (*.jpg)|*.jpg|GIF Files (*.gif)|*.gif"
				If openDialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
					Dim extension As String = Path.GetExtension(openDialog.SafeFileName)
					Me.radRichTextBox1.InsertImage(openDialog.OpenFile())
				End If

				Me.radRichTextBox1.Focus()
			End Using
		End Sub

		Private Sub radBtnSpellCheck_Click(ByVal sender As Object, ByVal e As EventArgs) Handles radBtnSpellCheck.Click
			Me.radSpellChecker1.Check(Me.radRichTextBox1)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnDecreaseIndent_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnDecreaseIndent.Click
			Me.radRichTextBox1.DecrementParagraphLeftIndent()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnIncreaseIndent_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnIncreaseIndent.Click
			Me.radRichTextBox1.IncrementParagraphLeftIndent()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnShowFormatting_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnShowFormatting.Click
			Me.radRichTextBox1.ToggleFormattingSymbols()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnFontSizeIncrease_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnFontSizeIncrease.Click
			Me.radRichTextBox1.IncrementFontSize()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnFontSizeDecrease_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnFontSizeDecrease.Click
			Me.radRichTextBox1.DecrementFontSize()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnFormattingClear_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnFormattingClear.Click
			Me.radRichTextBox1.ClearFormatting()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnUndo_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnUndo.Click
			Me.radRichTextBox1.Undo()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnRedo_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnRedo.Click
			Me.radRichTextBox1.Redo()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnCut_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnCut.Click
			Me.radRichTextBox1.Cut()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnCopy_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnCopy.Click
			Me.radRichTextBox1.Copy()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radButtonPaste_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radButtonPaste.Click
			Me.radRichTextBox1.Paste()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnHighlight_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnHighlight.Click
			Dim colorDialog As RadColorDialog = New RadColorDialog()

			If colorDialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
				Me.radRichTextBox1.ChangeTextHighlightColor(colorDialog.SelectedColor)
			End If

			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnFontColor_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles radBtnFontColor.Click
			Dim colorDialog As RadColorDialog = New RadColorDialog()

			If colorDialog.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK Then
				Me.radRichTextBox1.ChangeTextForeColor(colorDialog.SelectedColor)
			End If

			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radMenuItemInsertTable_Click(ByVal sender As Object, ByVal e As EventArgs)
			Using insertForm As InsertTableForm = New InsertTableForm()
				insertForm.Owner = Me

				If insertForm.ShowDialog() = System.Windows.Forms.DialogResult.OK Then
					Me.radRichTextBox1.InsertTable(insertForm.RowsCount, insertForm.ColumnsCount)
				End If
			End Using
		End Sub

		Private Sub radBtnBoldStyle_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnBoldStyle.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleBold()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnUnderlineStyle_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnUnderlineStyle.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleUnderline()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnItalicStyle_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnItalicStyle.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleItalic()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnStrikethrough_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnStrikethrough.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleStrikethrough()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnBulletList_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles radBtnBulletList.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim style As ListStyle = DefaultListStyles.None
			If args.ToggleState = ToggleState.On Then
				style = DefaultListStyles.Bulleted
			End If

			Me.radRichTextBox1.ChangeListStyle(style)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radNumberingList_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles radNumberingList.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim style As ListStyle = DefaultListStyles.None
			If args.ToggleState = ToggleState.On Then
				style = DefaultListStyles.Numbered
			End If

			Me.radRichTextBox1.ChangeListStyle(style)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnAligntLeft_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnAligntLeft.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim textAlignment As RadTextAlignment = RadTextAlignment.Justify
			If args.ToggleState = ToggleState.On Then
				textAlignment = RadTextAlignment.Left
			End If

			Me.radRichTextBox1.ChangeTextAlignment(textAlignment)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnAlignCenter_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnAlignCenter.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim textAlignment As RadTextAlignment = RadTextAlignment.Left
			If args.ToggleState = ToggleState.On Then
				textAlignment = RadTextAlignment.Center
			End If

			Me.radRichTextBox1.ChangeTextAlignment(textAlignment)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnAligntRight_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnAligntRight.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim textAlignment As RadTextAlignment = RadTextAlignment.Left
			If args.ToggleState = ToggleState.On Then
				textAlignment = RadTextAlignment.Right
			End If

			Me.radRichTextBox1.ChangeTextAlignment(textAlignment)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnAlignJustify_ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs) Handles radBtnAlignJustify.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim textAlignment As RadTextAlignment = RadTextAlignment.Left
			If args.ToggleState = ToggleState.On Then
				textAlignment = RadTextAlignment.Justify
			End If

			Me.radRichTextBox1.ChangeTextAlignment(textAlignment)
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnWebLayout_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles radBtnWebLayout.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim layout As DocumentLayoutMode = DocumentLayoutMode.Paged
			If args.ToggleState = ToggleState.On Then
				layout = DocumentLayoutMode.Flow
			End If

			Me.radRichTextBox1.LayoutMode = layout
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub radBtnPrintLayout_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles radBtnPrintLayout.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Dim layout As DocumentLayoutMode = DocumentLayoutMode.Flow
			If args.ToggleState = ToggleState.On Then
				layout = DocumentLayoutMode.Paged
			End If

			Me.radRichTextBox1.LayoutMode = layout
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub subscriptButtonElement_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles subscriptButtonElement.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleSubscript()
			Me.radRichTextBox1.Focus()
		End Sub

		Private Sub superscriptButtonElement_ToggleStateChanged(ByVal sender As Object, ByVal args As Telerik.WinControls.UI.StateChangedEventArgs) Handles superscriptButtonElement.ToggleStateChanged
			If stylesInitializing Then
				Return
			End If

			Me.radRichTextBox1.ToggleSuperscript()
			Me.radRichTextBox1.Focus()
		End Sub

		#End Region
	End Class
End Namespace
